# DATACATALOG

A work-in-progress Python package for building and maintaining the MongoDB-backed
SD2 Data Catalog. It is a dependency in the following repositories:
* capture-fixity-reactor
* etl-pipeline-support
* ingest-samples-json-reactor
* reprocess-uploads

More details will be forthcoming. For now, this is simply put for for reference
by folks who might be building against the schema or the Python library.

